EXPORTS

    ___lc_codepage_func
    ___lc_collate_cp_func
    ___lc_handle_func
    ___mb_cur_max_func
    ___setlc_active_func
    ___unguarded_readlc_active_add_func
    __argc
    __argv
    __badioinfo
    __CppXcptFilter
    __crtCompareStringA
    __crtCompareStringW
    __crtGetLocaleInfoW
    __crtGetStringTypeW
    __crtLCMapStringA
    __crtLCMapStringW
    __CxxFrameHandler
    __CxxFrameHandler2
    __CxxFrameHandler3
    __daylight
    __DestructExceptionObject
    __dllonexit
    __doserrno
    __dstbias
    __fpecode
    __getmainargs
    __initenv
    __iob_func
    __isascii
    __iscsym
    __iscsymf
    __lc_codepage
    __lc_collate_cp
    __lc_handle
    __lconv_init
    __mb_cur_max
    __pctype_func
    __pioinfo
    __pwctype_func
    __pxcptinfoptrs
    __RTCastToVoid
    __RTDynamicCast
    __RTtypeid
    __set_app_type
    __setlc_active
    __setusermatherr
    __STRINGTOLD
    __strncnt
    __threadhandle
    __threadid
    __toascii
    __uncaught_exception
    __unDName
    __unDNameEx
    __unguarded_readlc_active
    __wargv
    __wcserror
    __wcserror_s
    __wcsncnt
    __wgetmainargs
    __winitenv
    _abs64
    _access
    _access_s
    _acmdln
    _aexit_rtn
    _aligned_free
    _aligned_free_dbg
    _aligned_malloc
    _aligned_malloc_dbg
    _aligned_offset_malloc
    _aligned_offset_malloc_dbg
    _aligned_offset_realloc
    _aligned_offset_realloc_dbg
    _aligned_realloc
    _aligned_realloc_dbg
    _amsg_exit
    _assert
    _atodbl
    _atodbl_l
    _atof_l
    _atoflt_l
    _atoi_l
    _atoi64
    _atoi64_l
    _atol_l
    _atoldbl
    _atoldbl_l
    _beep
    _beginthread
    _beginthreadex
    _c_exit
    _cabs
    _callnewh
    _calloc_dbg
    _cexit
    _cgets
    _cgets_s
    _cgetws
    _cgetws_s
    _chdir
    _chdrive
    _chgsign
    _chmod
    _chsize
    _chsize_s
    _chvalidator
    _chvalidator_l
    _clearfp
    _close
    _commit
    _commode
    _control87
    _controlfp
    _controlfp_s
    _copysign
    _cprintf
    _cprintf_l
    _cprintf_p
    _cprintf_p_l
    _cprintf_s
    _cprintf_s_l
    _cputs
    _cputws
    _creat
    _crtAssertBusy
    _crtBreakAlloc
    _CrtCheckMemory
    _CrtDbgBreak
    _crtDbgFlag
    _CrtDbgReport
    _CrtDbgReportV
    _CrtDbgReportW
    _CrtDbgReportWV
    _CrtDoForAllClientObjects
    _CrtDumpMemoryLeaks
    _CrtIsMemoryBlock
    _CrtIsValidHeapPointer
    _CrtIsValidPointer
    _CrtMemCheckpoint
    _CrtMemDifference
    _CrtMemDumpAllObjectsSince
    _CrtMemDumpStatistics
    _CrtReportBlockType
    _CrtSetAllocHook
    _CrtSetBreakAlloc
    _CrtSetDbgBlockType
    _CrtSetDbgFlag
    _CrtSetDumpClient
    _CrtSetReportFile
    _CrtSetReportHook
    _CrtSetReportHook2
    _CrtSetReportMode
    _cscanf
    _cscanf_l
    _cscanf_s
    _cscanf_s_l
    _ctime32
    _ctime32_s
    _ctime64
    _ctime64_s
    _ctype
    _cwait
    _cwprintf
    _cwprintf_l
    _cwprintf_p
    _cwprintf_p_l
    _cwprintf_s
    _cwprintf_s_l
    _cwscanf
    _cwscanf_l
    _cwscanf_s
    _cwscanf_s_l
    _CxxThrowException
    _daylight
    _difftime32
    _difftime64
    _dstbias
    _dup
    _dup2
    _ecvt
    _ecvt_s
    _endthread
    _endthreadex
    _environ
    _eof
    _errno
    _execl
    _execle
    _execlp
    _execlpe
    _execv
    _execve
    _execvp
    _execvpe
    _exit
    _expand
    _expand_dbg
    _fcloseall
    _fcvt
    _fcvt_s
    _fdopen
    _fgetchar
    _fgetwchar
    _filbuf
    _fileinfo
    _filelength
    _filelengthi64
    _fileno
    _findclose
    _findfirst
    _findfirst64
    _findfirsti64
    _findnext
    _findnext64
    _findnexti64
    _finite
    _flsbuf
    _flushall
    _fmode
    _fpclass
    _fpreset
    _fprintf_l
    _fprintf_p
    _fprintf_p_l
    _fprintf_s_l
    _fputchar
    _fputwchar
    _free_dbg
    _freea
    _freea_s
    _fscanf_l
    _fscanf_s_l
    _fseeki64
    _fsopen
    _fstat
    _fstat64
    _fstati64
    _ftime
    _ftime32
    _ftime32_s
    _ftime64
    _ftime64_s
    _fullpath
    _fullpath_dbg
    _futime
    _futime32
    _futime64
    _fwprintf_l
    _fwprintf_p
    _fwprintf_p_l
    _fwprintf_s_l
    _fwscanf_l
    _fwscanf_s_l
    _gcvt
    _gcvt_s
    _get_doserrno
    _get_environ
    _get_errno
    _get_fileinfo
    _get_fmode
    _get_heap_handle
    _get_osfhandle
    _get_osplatform
    _get_osver
    _get_output_format
    _get_pgmptr
    _get_sbh_threshold
    _get_wenviron
    _get_winmajor
    _get_winminor
    _get_winver
    _get_wpgmptr
    _getch
    _getche
    _getcwd
    _Getdays
    _getdcwd
    _getdiskfree
    _getdrive
    _getdrives
    _getmaxstdio
    _getmbcp
    _Getmonths
    _getpid
    _getsystime
    _Gettnames
    _getw
    _getwch
    _getwche
    _getws
    _gmtime32
    _gmtime32_s
    _gmtime64
    _gmtime64_s
    _heapchk
    _heapmin
    _heapset
    _heapwalk
    _HUGE
    _hypot
    _i64toa
    _i64toa_s
    _i64tow
    _i64tow_s
    _initterm
    _initterm_e
    _invalid_parameter
    _iob
    _isalnum_l
    _isalpha_l
    _isatty
    _iscntrl_l
    _isctype
    _isctype_l
    _isdigit_l
    _isgraph_l
    _isleadbyte_l
    _islower_l
    _ismbbalnum
    _ismbbalnum_l
    _ismbbalpha
    _ismbbalpha_l
    _ismbbgraph
    _ismbbgraph_l
    _ismbbkalnum
    _ismbbkalnum_l
    _ismbbkana
    _ismbbkana_l
    _ismbbkprint
    _ismbbkprint_l
    _ismbbkpunct
    _ismbbkpunct_l
    _ismbblead
    _ismbblead_l
    _ismbbprint
    _ismbbprint_l
    _ismbbpunct
    _ismbbpunct_l
    _ismbbtrail
    _ismbbtrail_l
    _ismbcalnum
    _ismbcalnum_l
    _ismbcalpha
    _ismbcalpha_l
    _ismbcdigit
    _ismbcdigit_l
    _ismbcgraph
    _ismbcgraph_l
    _ismbchira
    _ismbchira_l
    _ismbckata
    _ismbckata_l
    _ismbcl0
    _ismbcl0_l
    _ismbcl1
    _ismbcl1_l
    _ismbcl2
    _ismbcl2_l
    _ismbclegal
    _ismbclegal_l
    _ismbclower
    _ismbclower_l
    _ismbcprint
    _ismbcprint_l
    _ismbcpunct
    _ismbcpunct_l
    _ismbcspace
    _ismbcspace_l
    _ismbcsymbol
    _ismbcsymbol_l
    _ismbcupper
    _ismbcupper_l
    _ismbslead
    _ismbslead_l
    _ismbstrail
    _ismbstrail_l
    _isnan
    _isprint_l
    _isspace_l
    _isupper_l
    _iswalnum_l
    _iswalpha_l
    _iswcntrl_l
    _iswctype_l
    _iswdigit_l
    _iswgraph_l
    _iswlower_l
    _iswprint_l
    _iswpunct_l
    _iswspace_l
    _iswupper_l
    _iswxdigit_l
    _isxdigit_l
    _itoa
    _itoa_s
    _itow
    _itow_s
    _j0
    _j1
    _jn
    _kbhit
    _lfind
    _lfind_s
    _localtime32
    _localtime32_s
    _localtime64
    _localtime64_s
    _lock
    _locking
    _logb
    _lrotl
    _lrotr
    _lsearch
    _lsearch_s
    _lseek
    _lseeki64
    _ltoa
    _ltoa_s
    _ltow
    _ltow_s
    _makepath
    _makepath_s
    _malloc_dbg
    _mbbtombc
    _mbbtombc_l
    _mbbtype
    _mbcasemap
    _mbccpy
    _mbccpy_l
    _mbccpy_s
    _mbccpy_s_l
    _mbcjistojms
    _mbcjistojms_l
    _mbcjmstojis
    _mbcjmstojis_l
    _mbclen
    _mbclen_l
    _mbctohira
    _mbctohira_l
    _mbctokata
    _mbctokata_l
    _mbctolower
    _mbctolower_l
    _mbctombb
    _mbctombb_l
    _mbctoupper
    _mbctoupper_l
    _mbctype
    _mblen_l
    _mbsbtype
    _mbsbtype_l
    _mbscat
    _mbscat_s
    _mbscat_s_l
    _mbschr
    _mbschr_l
    _mbscmp
    _mbscmp_l
    _mbscoll
    _mbscoll_l
    _mbscpy
    _mbscpy_s
    _mbscpy_s_l
    _mbscspn
    _mbscspn_l
    _mbsdec
    _mbsdec_l
    _mbsdup
    _mbsicmp
    _mbsicmp_l
    _mbsicoll
    _mbsicoll_l
    _mbsinc
    _mbsinc_l
    _mbslen
    _mbslen_l
    _mbslwr
    _mbslwr_l
    _mbslwr_s
    _mbslwr_s_l
    _mbsnbcat
    _mbsnbcat_l
    _mbsnbcat_s
    _mbsnbcat_s_l
    _mbsnbcmp
    _mbsnbcmp_l
    _mbsnbcnt
    _mbsnbcnt_l
    _mbsnbcoll
    _mbsnbcoll_l
    _mbsnbcpy
    _mbsnbcpy_l
    _mbsnbcpy_s
    _mbsnbcpy_s_l
    _mbsnbicmp
    _mbsnbicmp_l
    _mbsnbicoll
    _mbsnbicoll_l
    _mbsnbset
    _mbsnbset_l
    _mbsnbset_s
    _mbsnbset_s_l
    _mbsncat
    _mbsncat_l
    _mbsncat_s
    _mbsncat_s_l
    _mbsnccnt
    _mbsnccnt_l
    _mbsncmp
    _mbsncmp_l
    _mbsncoll
    _mbsncoll_l
    _mbsncpy
    _mbsncpy_l
    _mbsncpy_s
    _mbsncpy_s_l
    _mbsnextc
    _mbsnextc_l
    _mbsnicmp
    _mbsnicmp_l
    _mbsnicoll
    _mbsnicoll_l
    _mbsninc
    _mbsninc_l
    _mbsnlen
    _mbsnlen_l
    _mbsnset
    _mbsnset_l
    _mbsnset_s
    _mbsnset_s_l
    _mbspbrk
    _mbspbrk_l
    _mbsrchr
    _mbsrchr_l
    _mbsrev
    _mbsrev_l
    _mbsset
    _mbsset_l
    _mbsset_s
    _mbsset_s_l
    _mbsspn
    _mbsspn_l
    _mbsspnp
    _mbsspnp_l
    _mbsstr
    _mbsstr_l
    _mbstok
    _mbstok_l
    _mbstok_s
    _mbstok_s_l
    _mbstowcs_l
    _mbstowcs_s_l
    _mbstrlen
    _mbstrlen_l
    _mbstrnlen
    _mbstrnlen_l
    _mbsupr
    _mbsupr_l
    _mbsupr_s
    _mbsupr_s_l
    _mbtowc_l
    _memccpy
    _memicmp
    _memicmp_l
    _mkdir
    _mkgmtime
    _mkgmtime32
    _mkgmtime64
    _mktemp
    _mktemp_s
    _mktime32
    _mktime64
    _msize
    _nextafter
    _onexit
    _open
    _open_osfhandle
    _osplatform
    _osver
    _pclose
    _pctype
    _pgmptr
    _pipe
    _popen
    _printf_l
    _printf_p
    _printf_p_l
    _printf_s_l
    _purecall
    _putch
    _putenv
    _putenv_s
    _putw
    _putwch
    _putws
    _pwctype
    _read
    _realloc_dbg
    _resetstkoflw
    _rmdir
    _rmtmp
    _rotl
    _rotl64
    _rotr
    _rotr64
    _scalb
    _scanf_l
    _scanf_s_l
    _scprintf
    _scprintf_l
    _scprintf_p_l
    _scwprintf
    _scwprintf_l
    _scwprintf_p_l
    _searchenv
    _searchenv_s
    _set_controlfp
    _set_doserrno
    _set_errno
    _set_error_mode
    _set_fileinfo
    _set_fmode
    _set_output_format
    _set_sbh_threshold
    _seterrormode
    _setjmp
    _setmaxstdio
    _setmbcp
    _setmode
    _setsystime
    _sleep
    _snprintf
    _snprintf_c
    _snprintf_c_l
    _snprintf_l
    _snprintf_s
    _snprintf_s_l
    _snscanf
    _snscanf_l
    _snscanf_s
    _snscanf_s_l
    _snwprintf
    _snwprintf_l
    _snwprintf_s
    _snwprintf_s_l
    _snwscanf
    _snwscanf_l
    _snwscanf_s
    _snwscanf_s_l
    _sopen
    _sopen_s
    _spawnl
    _spawnle
    _spawnlp
    _spawnlpe
    _spawnv
    _spawnve
    _spawnvp
    _spawnvpe
    _splitpath
    _splitpath_s
    _sprintf_l
    _sprintf_p_l
    _sprintf_s_l
    _sscanf_l
    _sscanf_s_l
    _stat
    _stat64
    _stati64
    _statusfp
    _strcmpi
    _strcoll_l
    _strdate
    _strdate_s
    _strdup
    _strdup_dbg
    _strerror
    _strerror_s
    _Strftime
    _stricmp
    _stricmp_l
    _stricoll
    _stricoll_l
    _strlwr
    _strlwr_l
    _strlwr_s
    _strlwr_s_l
    _strncoll
    _strncoll_l
    _strnicmp
    _strnicmp_l
    _strnicoll
    _strnicoll_l
    _strnset
    _strnset_s
    _strrev
    _strset
    _strset_s
    _strtime
    _strtime_s
    _strtod_l
    _strtoi64
    _strtoi64_l
    _strtol_l
    _strtoui64
    _strtoui64_l
    _strtoul_l
    _strupr
    _strupr_l
    _strupr_s
    _strupr_s_l
    _strxfrm_l
    _swab
    _swprintf
    _swprintf_c
    _swprintf_c_l
    _swprintf_p_l
    _swprintf_s_l
    _swscanf_l
    _swscanf_s_l
    _sys_errlist
    _sys_nerr
    _tell
    _telli64
    _tempnam
    _tempnam_dbg
    _time32
    _time64
    _timezone
    _tolower
    _tolower_l
    _toupper
    _toupper_l
    _towlower_l
    _towupper_l
    _tzname
    _tzset
    _ui64toa
    _ui64toa_s
    _ui64tow
    _ui64tow_s
    _ultoa
    _ultoa_s
    _ultow
    _ultow_s
    _umask
    _umask_s
    _ungetch
    _ungetwch
    _unlink
    _unlock
    _utime
    _utime32
    _utime64
    _vcprintf
    _vcprintf_l
    _vcprintf_p
    _vcprintf_p_l
    _vcprintf_s
    _vcprintf_s_l
    _vcwprintf
    _vcwprintf_l
    _vcwprintf_p
    _vcwprintf_p_l
    _vcwprintf_s
    _vcwprintf_s_l
    _vfprintf_l
    _vfprintf_p
    _vfprintf_p_l
    _vfprintf_s_l
    _vfwprintf_l
    _vfwprintf_p
    _vfwprintf_p_l
    _vfwprintf_s_l
    _vprintf_l
    _vprintf_p
    _vprintf_p_l
    _vprintf_s_l
    _vscprintf
    _vscprintf_l
    _vscprintf_p_l
    _vscwprintf
    _vscwprintf_l
    _vscwprintf_p_l
    _vsnprintf
    _vsnprintf_c
    _vsnprintf_c_l
    _vsnprintf_l
    _vsnprintf_s
    _vsnprintf_s_l
    _vsnwprintf
    _vsnwprintf_l
    _vsnwprintf_s
    _vsnwprintf_s_l
    _vsprintf_l
    _vsprintf_p
    _vsprintf_p_l
    _vsprintf_s_l
    _vswprintf
    _vswprintf_c
    _vswprintf_c_l
    _vswprintf_l
    _vswprintf_p_l
    _vswprintf_s_l
    _vwprintf_l
    _vwprintf_p
    _vwprintf_p_l
    _vwprintf_s_l
    _waccess
    _waccess_s
    _wasctime
    _wasctime_s
    _wassert
    _wchdir
    _wchmod
    _wcmdln
    _wcreat
    _wcscoll_l
    _wcsdup
    _wcsdup_dbg
    _wcserror
    _wcserror_s
    _wcsftime_l
    _wcsicmp
    _wcsicmp_l
    _wcsicoll
    _wcsicoll_l
    _wcslwr
    _wcslwr_l
    _wcslwr_s
    _wcslwr_s_l
    _wcsncoll
    _wcsncoll_l
    _wcsnicmp
    _wcsnicmp_l
    _wcsnicoll
    _wcsnicoll_l
    _wcsnset
    _wcsnset_s
    _wcsrev
    _wcsset
    _wcsset_s
    _wcstoi64
    _wcstoi64_l
    _wcstol_l
    _wcstombs_l
    _wcstombs_s_l
    _wcstoui64
    _wcstoui64_l
    _wcstoul_l
    _wcsupr
    _wcsupr_l
    _wcsupr_s
    _wcsupr_s_l
    _wcsxfrm_l
    _wctime
    _wctime32
    _wctime32_s
    _wctime64
    _wctime64_s
    _wctomb_l
    _wctomb_s_l
    _wctype
    _wenviron
    _wexecl
    _wexecle
    _wexeclp
    _wexeclpe
    _wexecv
    _wexecve
    _wexecvp
    _wexecvpe
    _wfdopen
    _wfindfirst
    _wfindfirst64
    _wfindfirsti64
    _wfindnext
    _wfindnext64
    _wfindnexti64
    _wfopen
    _wfopen_s
    _wfreopen
    _wfreopen_s
    _wfsopen
    _wfullpath
    _wfullpath_dbg
    _wgetcwd
    _wgetdcwd
    _wgetenv
    _wgetenv_s
    _winmajor
    _winminor
    _winput_s
    _winver
    _wmakepath
    _wmakepath_s
    _wmkdir
    _wmktemp
    _wmktemp_s
    _wopen
    _woutput_s
    _wperror
    _wpgmptr
    _wpopen
    _wprintf_l
    _wprintf_p
    _wprintf_p_l
    _wprintf_s_l
    _wputenv
    _wputenv_s
    _wremove
    _wrename
    _write
    _wrmdir
    _wscanf_l
    _wscanf_s_l
    _wsearchenv
    _wsearchenv_s
    _wsetlocale
    _wsopen
    _wsopen_s
    _wspawnl
    _wspawnle
    _wspawnlp
    _wspawnlpe
    _wspawnv
    _wspawnve
    _wspawnvp
    _wspawnvpe
    _wsplitpath
    _wsplitpath_s
    _wstat
    _wstat64
    _wstati64
    _wstrdate
    _wstrdate_s
    _wstrtime
    _wstrtime_s
    _wsystem
    _wtempnam
    _wtempnam_dbg
    _wtmpnam
    _wtmpnam_s
    _wtof
    _wtof_l
    _wtoi
    _wtoi_l
    _wtoi64
    _wtoi64_l
    _wtol
    _wtol_l
    _wunlink
    _wutime
    _wutime32
    _wutime64
    _XcptFilter
    _y0
    _y1
    _yn
    abort
    abs
    acos
    asctime
    asctime_s
    asin
    atan
    atan2
    atexit
    atof
    atoi
    atol
    bsearch
    bsearch_s
    btowc
    calloc
    ceil
    clearerr
    clearerr_s
    clock
    cos
    cosh
    ctime
    difftime
    div
    exit
    exp
    fabs
    fclose
    feof
    ferror
    fflush
    fgetc
    fgetpos
    fgets
    fgetwc
    fgetws
    floor
    fmod
    fopen
    fopen_s
    fprintf
    fprintf_s
    fputc
    fputs
    fputwc
    fputws
    fread
    free
    freopen
    freopen_s
    frexp
    fscanf
    fscanf_s
    fseek
    fsetpos
    ftell
    fwprintf
    fwprintf_s
    fwrite
    fwscanf
    fwscanf_s
    getc
    getchar
    getenv
    getenv_s
    gets
    getwc
    getwchar
    gmtime
    is_wctype
    isalnum
    isalpha
    iscntrl
    isdigit
    isgraph
    isleadbyte
    islower
    isprint
    ispunct
    isspace
    isupper
    iswalnum
    iswalpha
    iswascii
    iswcntrl
    iswctype
    iswdigit
    iswgraph
    iswlower
    iswprint
    iswpunct
    iswspace
    iswupper
    iswxdigit
    isxdigit
    labs
    ldexp
    ldiv
    localeconv
    localtime
    log
    log10
    longjmp
    malloc
    mblen
    mbrlen
    mbrtowc
    mbsdup_dbg
    mbsrtowcs
    mbsrtowcs_s
    mbstowcs
    mbstowcs_s
    mbtowc
    memchr
    memcmp
    memcpy
    memcpy_s
    memmove
    memmove_s
    memset
    mktime
    modf
    perror
    pow
    printf
    printf_s
    putc
    putchar
    puts
    putwc
    putwchar
    qsort
    qsort_s
    raise
    rand
    rand_s
    realloc
    remove
    rename
    rewind
    scanf
    scanf_s
    setbuf
    setlocale
    setvbuf
    signal
    sin
    sinh
    sprintf
    sprintf_s
    sqrt
    srand
    sscanf
    sscanf_s
    strcat
    strcat_s
    strchr
    strcmp
    strcoll
    strcpy
    strcpy_s
    strcspn
    strerror
    strerror_s
    strftime
    strlen
    strncat
    strncat_s
    strncmp
    strncpy
    strncpy_s
    strnlen
    strpbrk
    strrchr
    strspn
    strstr
    strtod
    strtok
    strtok_s
    strtol
    strtoul
    strxfrm
    swprintf
    swprintf_s
    swscanf
    swscanf_s
    system
    tan
    tanh
    time
    tmpfile
    tmpfile_s
    tmpnam
    tmpnam_s
    tolower
    toupper
    towlower
    towupper
    ungetc
    ungetwc
    utime
    vfprintf
    vfprintf_s
    vfwprintf
    vfwprintf_s
    vprintf
    vprintf_s
    vsnprintf
    vsprintf
    vsprintf_s
    vswprintf
    vswprintf_s
    vwprintf
    vwprintf_s
    wcrtomb
    wcrtomb_s
    wcscat
    wcscat_s
    wcschr
    wcscmp
    wcscoll
    wcscpy
    wcscpy_s
    wcscspn
    wcsftime
    wcslen
    wcsncat
    wcsncat_s
    wcsncmp
    wcsncpy
    wcsncpy_s
    wcsnlen
    wcspbrk
    wcsrchr
    wcsrtombs
    wcsrtombs_s
    wcsspn
    wcsstr
    wcstod
    wcstok
    wcstok_s
    wcstol
    wcstombs
    wcstombs_s
    wcstoul
    wcsxfrm
    wctob
    wctomb
    wctomb_s
    wprintf
    wprintf_s
    wscanf
    wscanf_s
